@@ -3,7 +3,7 @@
 #----------------------------------------------------------------------
 # xoutil.tests.test_bases
 #----------------------------------------------------------------------
-# Copyright (c) 2013 Merchise Autrement and Contributors
+# Copyright (c) 2013, 2014 Merchise Autrement and Contributors
 # All rights reserved.
 #
 # This is free software; you can redistribute it and/or modify it under
@@ -28,12 +28,12 @@ __date__   = "Mon Mar 25 14:36:30 2013"
 def build_many_tests():
     def test_many_random_convertions(self):
         subjects = [B32, B64]
-        for _ in range(10**3):
+        for _ in range(5):
             testcase = random.randrange(0, 2**128)
             subject = random.choice(subjects)
             assert testcase ==  subject.basetoint(subject.inttobase(testcase))
     return {'test_many_random_convertions_%d' % i:
-            test_many_random_convertions for i in range(100)}
+            test_many_random_convertions for i in range(10)}
 
 _TestManyConvertions = type(str('TestManyConvertions'),
                            (object, ),
