@@ -35,8 +35,7 @@ class DeprecationError(Exception):
     pass
 
 
-# WARNING!!! Don't make deprecated depends upon anything more than compat and
-# decorator.py, since this is meant to be used by all others xoutil modules.
+# WARNING!!! Don't make deprecated depends upon anything more than compat.
 def deprecated(replacement, msg=DEFAULT_MSG, deprecated_module=None,
                removed_in_version=None, check_version=False):
     '''Small decorator for deprecated functions.
@@ -51,7 +50,7 @@ def deprecated(replacement, msg=DEFAULT_MSG, deprecated_module=None,
        deprecated.
 
     :param msg: A deprecation warning message template.  You should provide
-       keyword arguments for the :py:func:`format` function.  Currently we pass
+       keyword arguments for the :func:`format` function.  Currently we pass
        the current keyword arguments: `replacement` (after some processing),
        `funcname` with the name of the currently deprecated object and
        `in_version` with the version this object is going to be removed if
